function x = solve_transition(Rpath,COUNTRIES);

GLOBALS

T               = 150;                      % # of years
T0              = 50;                       % # of years with demographics
TR              = size(Rpath,1);

Rpath           = [Rpath; (1/bta-1)*ones(T-TR,1)];

resultfile = ['results\res' fileext '.mat'];
fid = fopen(resultfile);
if fid == -1, for i=COUNTRIES, res(i).x=[]; end
else, fclose(fid); load(resultfile); end 

  
P = 1;
for t=2:T,
P = [P; P(end)/(1+Rpath(t))]; 
end
CumR            = cumprod([1; (1+Rpath(2:end)).^-1]);

if GRAPHS
subplot(2,2,3), hold on
plot(Rpath), drawnow, hold off
end


KY   = theta ./ ((1+tauPI).*Rpath + delta);
w    = (1-theta)*KY.^(theta/(1-theta)); 
R    = 1+Rpath;

% countries:
% 1=dk, 2=fi, 3=no, 4=sw, 5=uk, 6=be, 7=fr
% 8=de, 9=nl, 10=it, 11=po, 12=sp
cty_txt = ['dk'; 'fi'; 'no'; 'sw'; 'uk'; 'be'; ...
           'fr'; 'de'; 'nl'; 'it'; 'po'; 'sp'; ...
           'ca'; 'us'; 'jp'];

load popdata/countryValues;             % POPpath ETApath EFFpath init_values
allETApaths = ETApath;
allEFFpaths = EFFpath;
allPOPpaths = POPpath;

load(INITIALSSFILE)

if length(COUNTRIES) > 1
  COUNTRYWEIGHT   = country_weight./(ones(15,1)*sum(country_weight(COUNTRIES,:)));
else COUNTRYWEIGHT = ones(1,size(country_weight,2));
end

for cty = COUNTRIES

  country   = cty_txt(cty,:);

  ETApath   = allETApaths(cty,:);                     % Pop aged 20-64 / total pop. First year = 2000
  EFFpath   = allEFFpaths(cty,:);                     % Pop aged 20-64 / total pop. First year = 2000
  POPpath   = allPOPpaths(cty,:)/allPOPpaths(cty,1);
  ETApath   = [ETApath(2:T0+1) ETApath(T0+1)*ones(1,T-T0)]';
  POPpath   = [POPpath(2:T0+1) POPpath(T0+1)*ones(1,T-T0)]';
  tauC      = init_values(cty,2);
  

  A0        = initialA(cty);
  D0        = initialD(cty);
  B0        = initialB(cty);                          % Transf. per capita in levels
  G0        = initialG(cty);

  EFFpath   = EFFpath * initialEFF(cty);              % Adjust for productivity differences
  EFFpath   = [EFFpath(2:T0+1) EFFpath(T0+1)*ones(1,T-T0)]';

  % =======================================================================
  % Solve for policy
  % =======================================================================

  if BALANCEBUDGET


    % =======================================================================
    % Solve for balanced-budget policy
    % =======================================================================
    x              = ones(2*T+1,1);
    x(1:T)         = 0;
    x(T+1:2*T)     = log(initialCA(cty));
    x(2*T+1)       = .5;
    if ~isempty(res(cty).x), if isreal(res(cty).x), x=res(cty).x; end, end

    [x, rc]        = csolve('eq_balbud',x,[],1e-10,20,T,P,Rpath,POPpath);
   
    if rc > 0,       prints('*** Did not solve gvtproblem, cty = ',cty,8,0,0), end
    tau            = exp(x(1:T))./(1+exp(x(1:T)));
    ca             = exp(x(T+1:2*T));
    h              = ((1-tau).*EFFpath.*w./(zeta.*(1+gmma).*ca.*(1+tauC))).^(1/gmma);
    ci             = U1(ca,h).^(-1/muI);
 
  else


    % =======================================================================
    % Solve for optimal policy
    % =======================================================================
    
    if AUTARKY
      x              = zeros(5*T+1,1);
      x(1)           = -.1;                    % guess for rho1
      x(2:T+1)       = P;                      % rho2
      x(T+2:2*T+1)   = .1;                     % rho4
      x(2*T+2:3*T+1) = log(initialCA(cty));    % ca
      x(3*T+2:4*T+1) = -.5;                    % h
      x(4*T+2:5*T+1) = log(A0-D0);             % k'
      if ~isempty(res(cty).x), if isreal(res(cty).x), if length(res(cty).x)==length(x), x=res(cty).x; end, end, end

      [x, rc]        = csolve('eq_optimal_autarky',x,[],1e-9,30,T,POPpath);
  
      if rc > 0,       prints('*** Did not solve gvtproblem, cty = ',cty,8,0,0), end
      ca             = exp(x(2*T+2:3*T+1));
      h              = exp(x(3*T+2:4*T+1,:))./(1+exp(x(3*T+2:4*T+1,:)));
      K              = exp(x(4*T+2:5*T+1));
      K              = [(A0-D0); K(1:end-1)];
      H              = ETApath.*EFFpath.*h;
      Y              = K.^theta .* (POPpath.*H).^(1-theta);
      KY             = K./Y;
      Rpath          = (theta*Y./K-delta) / (1+tauPI);
      w              = (1-theta)*KY.^(theta/(1-theta)); 
      R              = 1+Rpath;
      tau            = 1 + U3(ca,h)./U1(ca,h).*(1+tauC)./(w.*EFFpath);
      ci             = U1(ca,h).^(-1/muI);
      P = 1;           for t=2:T, P = [P; P(end)/(1+Rpath(t))]; end
      
    else
      x              = zeros(3*T+2,1);
      x(1)           = -.1;                    % guess for rho1
      x(2)           = -50;                    % rho2
      x(3:T+2)       = .1;                     % rho4
      x(T+3:2*T+2)   = log(initialCA(cty));    % ca
      x(2*T+3:3*T+2) = log(initialH(cty));     % h
      if ~isempty(res(cty).x), if isreal(res(cty).x), x=res(cty).x; end, end

      [x, rc]        = csolve('eq_optimal',x,[],1e-9,10,T,CumR,Rpath,POPpath);
  
      if rc > 0,       prints('*** Did not solve gvtproblem, cty = ',cty,8,0,0), end
      ca             = exp(x(T+3:2*T+2));
      h              = exp(x(2*T+3:3*T+2));
      tau            = 1 + U3(ca,h)./U1(ca,h).*(1+tauC)./(w.*EFFpath);
      ci             = U1(ca,h).^(-1/muI);
    end
  
    
  end


  % =======================================================================
  % Implications of policy on economy
  % =======================================================================

  H    = ETApath.*EFFpath.*h;
  K    = KY.^(1/(1-theta)).*POPpath.*H;
  Y    = K.^theta .* (POPpath.*H).^(1-theta);
  C    = ETApath.*ca + (1-ETApath).*ci;

  d = D0;
  a = A0;
  for t = 1:T;
    d(t+1)  = R(t)*d(t) + POPpath(t)*(G0 + B0 - ...
                tau(t)*w(t)*H(t) - tauC*C(t)) - tauPI*Rpath(t)*K(t);
    a(t+1)  = (1+Rpath(t))*a(t) + POPpath(t)*((1-tau(t))*w(t)*H(t) ...
                + B0 - (1+tauC)*C(t));
  end



  % Check HBC
  hbc1   = (1+tauC)*(ETApath.*ca+(1-ETApath).*ci) - (1-tau).*w.*H - B0;
  hbc2   = sum(P.*POPpath.* hbc1);
  rrr    = 1 + Rpath(end);
  hbc3   = P(end,1) * POPpath(end) * hbc1(end,:) / (rrr * (1-1/rrr));
  hbc    = hbc2 + hbc3 - (1 + Rpath(1))*A0;

  
  % Check GBC
  GBC    = Rpath.*d(1:T)' + POPpath.*(G0 + B0 - tau.*w.*H) - ...
           tauPI*Rpath.*K - POPpath.*tauC.*C;
  gbc    = G0 + C - tauPI*Rpath.*K./POPpath - w.*H;

  if abs(hbc)>1e-8, prints('HBC not fulfilled! cty, hbc = ',[cty hbc],10,6,0); end
  if BALANCEBUDGET
     if max(abs(GBC)) > 1e-6, fprintf(1,'GBC not fulfilled! cty = %4d, gbc = %10.6f\n',cty,GBC(end)); end
  elseif abs(GBC(end))>1e-5, fprintf(1,'GBC not fulfilled! cty = %4d, gbc = %10.6f\n',cty,GBC(end)); end

  res(cty).country = country;
  res(cty).ca      = ca;
  res(cty).ci      = ci;
  res(cty).h       = h;
  res(cty).C       = C;
  res(cty).Y       = Y;
  res(cty).K       = K;
  res(cty).H       = H;
  res(cty).tau     = tau;
  res(cty).a       = a(1:end-1)';
  res(cty).d       = d(1:end-1)';
  res(cty).rc      = rc;
  res(cty).x       = x;
  res(cty).Rpath   = Rpath;
  res(cty).initial = [mu gmma zeta]';
  res(cty).eta     = ETApath;
  res(cty).eff     = EFFpath;
  res(cty).pop     = POPpath;
  res(cty).pop0    = allPOPpaths(cty,1);
  if length(COUNTRIES) > 1
    res(cty).CountryWeight = [COUNTRYWEIGHT(cty,2:T0+1) COUNTRYWEIGHT(cty,T0+1)*ones(1,T-T0)]';
  else res(cty).CountryWeight = 1; end
  res(cty).policy  = [BALANCEBUDGET OPTIM_BAL AUTARKY CONSTANTR VARYELAST INITIATESS];

end

save(resultfile,'res')


Y   = [res(COUNTRIES).Y].*(ones(T,1)*[res(COUNTRIES).pop0]);
K   = [res(COUNTRIES).K].*(ones(T,1)*[res(COUNTRIES).pop0]);
A   = [res(COUNTRIES).a].*(ones(T,1)*[res(COUNTRIES).pop0]);
D   = [res(COUNTRIES).d].*(ones(T,1)*[res(COUNTRIES).pop0]);

if length(COUNTRIES) == 1
    x = (A-K-D) ./ A;
    if GRAPHS, subplot(2,2,4), plot([(A-D)./Y K./Y]); title('(A-D)/Y, K/Y'); drawnow, end
else    
    x   = sum(A'-K'-D')' ./ sum(A')';
    if GRAPHS, subplot(2,2,4), plot([sum(A'-D')'./sum(Y')' sum(K')'./sum(Y')']); title('(A-D)/Y, K/Y'); drawnow, end
    implied_R   = (theta ./ (sum(A'-D')./sum(Y')) - delta) ./ (1+tauPI);
    implied_R   = implied_R(1:TR);
    save results\temp KY K Y x implied_R
end

x           = x(1:TR);


