% Welfare analysis

clear all

GLOBALS

T       = 150;


% Preferences
mu       = 2;
muI      = mu;
gmma     = 1/.3;
zeta     = 30;

load results\initial_ss

load results\res_op;       res_op       = res;
load results\res_op_cr;    res_cr       = res;
load results\res_op_au;    res_au       = res;
load results\res_op_eu;    res_eu       = res;
load results\res_bb;       res_bb       = res;
load results\res_ob;       res_ob       = res;

clear res

EU_COUNTRIES = [1 2 4 5 6 7 8 9 10 11 12];

TOTAL_WELF   = zeros(1,7);


COUNTRIES = 1:15;

for cty = COUNTRIES

    rop             = res_op(cty);
    rcr             = res_cr(cty);
    rau             = res_au(cty);
    rbb             = res_bb(cty);
    rob             = res_ob(cty);

    eu_cty          = find(EU_COUNTRIES == cty);
    if isempty(eu_cty)
        reu         = res_eu(1);
    else
        reu         = res_eu(cty);
    end

    p               = rop.pop;

    Uop             = p.*bta.^(0:T-1)'.*U(rop.ca,rop.ci,rop.h,rop.eta);
    Ucr             = p.*bta.^(0:T-1)'.*U(rcr.ca,rcr.ci,rcr.h,rcr.eta);
    Uau             = p.*bta.^(0:T-1)'.*U(rau.ca,rau.ci,rau.h,rau.eta);
    Ueu             = p.*bta.^(0:T-1)'.*U(reu.ca,reu.ci,reu.h,reu.eta);
    Ubb             = p.*bta.^(0:T-1)'.*U(rbb.ca,rbb.ci,rbb.h,rbb.eta);
    Uob             = p.*bta.^(0:T-1)'.*U(rob.ca,rob.ci,rob.h,rob.eta);


    UopS            = sum(Uop)+bta*Uop(end)/(1-bta);
    UcrS            = sum(Ucr)+bta*Ucr(end)/(1-bta);
    UauS            = sum(Uau)+bta*Uau(end)/(1-bta);
    UeuS            = sum(Ueu)+bta*Ueu(end)/(1-bta);
    UbbS            = sum(Ubb)+bta*Ubb(end)/(1-bta);
    UobS            = sum(Uob)+bta*Uob(end)/(1-bta);

    welf(cty).wgcr  = (UcrS/UopS)^(1/(1-mu))-1;          % Welfare gain
    welf(cty).wgau  = (UauS/UopS)^(1/(1-mu))-1;         
    welf(cty).wgeu  = (UeuS/UopS)^(1/(1-mu))-1;         
    welf(cty).wgbb  = (UbbS/UopS)^(1/(1-mu))-1;         
    welf(cty).wgob  = (UobS/UopS)^(1/(1-mu))-1;         
    
    TOTAL_WELF      = TOTAL_WELF + rop.pop0 * [UopS UcrS UauS 0 UbbS UobS 0];
    if ~isempty(eu_cty)
        TOTAL_WELF(4) = TOTAL_WELF(4) + rop.pop0 * UeuS;
        TOTAL_WELF(7) = TOTAL_WELF(7) + rop.pop0 * UopS;
    end
    
end


cty_txt  = ['dk'; 'fi'; 'no'; 'sw'; 'uk'; 'be'; ...
           'fr'; 'de'; 'nl'; 'it'; 'po'; 'sp'; ...
           'ca'; 'us'; 'jp'];

fprintf(1,'Table 8: Welfare gain with other prices\n');
fprintf(1,    'cy:      constant r   autarky    EU    all balance   other balance\n')
for cty = [6 13 1 2 7 8 10 15 9 3 11 12 4 5 14]
    eu_cty          = find(EU_COUNTRIES == cty);
    if isempty(eu_cty)
        fprintf(1,'%2s:        %5.2f     %5.2f    %5.2f     %5.2f           %5.2f\n',cty_txt(cty,:),...
              100*[welf(cty).wgcr welf(cty).wgau -0.0999 welf(cty).wgbb welf(cty).wgob])
    else
        fprintf(1,'%2s:        %5.2f     %5.2f    %5.2f     %5.2f           %5.2f\n',cty_txt(cty,:),...
              100*[welf(cty).wgcr welf(cty).wgau welf(cty).wgeu welf(cty).wgbb welf(cty).wgob])
    end
end

fprintf(1,'World:     %5.2f     %5.2f    %5.2f     %5.2f           %5.2f\n',...
              100*((TOTAL_WELF(2:6)./TOTAL_WELF([1 1 7 1 1])).^(1/(1-mu))-1))
    
